@@ -11,6 +11,15 @@
 		}		
 	}
 	
+	classes <- system.file("java", package = "JavaGD", lib.loc = NULL)
+	if (nchar(classes)) {
+		.jaddClassPath(classes)
+		jars <- grep(".*\\.jar", list.files(classes, full.names = TRUE), TRUE, value = TRUE)
+		if (length(jars)) { 
+			.jaddClassPath(jars)
+		}		
+	}
+	
 	# If we have a rJava version < 0.8-3 load JRIEngine.jar and REngine.jar
 	#if (installed.packages()['rJava','Version']<"0.8-3")  {
         if (!is.null(sessionInfo()$otherPkgs$rJava$Version) && sessionInfo()$otherPkgs$rJava$Version < "0.8-3") {
@@ -25,8 +34,8 @@
 	}
 	
 	## we supply our own JavaGD class
-	#.setenv <- if (exists("Sys.setenv")) Sys.setenv else Sys.putenv
-	#.setenv("JAVAGD_CLASS_NAME"="org/mutoss/gui/JavaGD")  
+	.setenv <- if (exists("Sys.setenv")) Sys.setenv else Sys.putenv
+	.setenv("JAVAGD_CLASS_NAME"="org/mutoss/gui/JavaGD")  
 	
 	# Optional Deducer integration:
 	if(exists(".deducer")) {
