@@ -54,7 +54,7 @@ public class AboutDialog extends JDialog implements ActionListener {
 					"gMCP-GUI"+"\n\n", getH1());			
 			doc.insertString(doc.getLength(),
 					"by Kornelius Rohmeyer is distributed under GPL>=2.0."+"\n\n", getT());			
-			doc.insertString(doc.getLength(), "This program uses the libraries log4j, iText (2.1.4), jxlayer, swingworker and JGoodies Forms.\n", getT());
+			doc.insertString(doc.getLength(), "This program uses the libraries log4j, JLaTeXMath, iText (2.1.4), jxlayer,\n swingworker, commons logging/lang, JRI and JGoodies Forms.\n", getT());
 			doc.setParagraphAttributes(0, doc.getLength(), getC(), true);
         } catch (BadLocationException ble) {
 
