@@ -8,9 +8,13 @@ import java.awt.print.PageFormat;
 import java.awt.print.Printable;
 import java.awt.print.PrinterException;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 
 public class PrintableObject implements Printable {
+	
 	private NetList nl;
+	protected static Log logger = LogFactory.getLog(PrintableObject.class);
 
 	public PrintableObject(NetList nl) {
 		this.nl = nl;
@@ -27,8 +31,8 @@ public class PrintableObject implements Printable {
 			Dimension dim = nl.getSize();
 
 			g2.translate(pf.getImageableX(), pf.getImageableY());
-			System.out.println("" + width + " " + dim.getWidth() + " " + height
-					+ " " + dim.getHeight());
+			logger.info("Size (" + width + " - " + dim.getWidth() 
+					+ ", " + height	+ " " + dim.getHeight() + ")");
 			double scale = Math.min(width / dim.getWidth(), height / dim.getHeight());
 			g2.scale(scale, scale);
 			nl.setBackground(Color.white);
